@@ -511,6 +511,7 @@ class AtomicTransactionComposer:
                             return_value=return_value,
                             decode_error=decode_error,
                             tx_info=tx_info,
+                            method=self.method_dict[i],
                         )
                     )
                     continue
@@ -545,6 +546,7 @@ class AtomicTransactionComposer:
                 return_value=return_value,
                 decode_error=decode_error,
                 tx_info=tx_info,
+                method=self.method_dict[i],
             )
             method_results.append(abi_result)
 
@@ -692,12 +694,14 @@ class ABIResult:
         return_value: Any,
         decode_error: Optional[Exception],
         tx_info: dict,
+        method: abi.Method,
     ) -> None:
         self.tx_id = tx_id
         self.raw_value = raw_value
         self.return_value = return_value
         self.decode_error = decode_error
         self.tx_info = tx_info
+        self.method = method
 
 
 class AtomicTransactionResponse:
