@@ -26,6 +26,8 @@ ASSETTRANSFER_TXN = "axfer"
 """str: indicates an asset transfer transaction"""
 APPCALL_TXN = "appl"
 """str: indicates an app call transaction, allows creating, deleting, and interacting with an application"""
+STATEPROOF_TXN = "stpf"
+"""str: indicates an state proof transaction"""
 
 # note field types
 NOTE_FIELD_TYPE_DEPOSIT = "d"
@@ -134,3 +136,4 @@ max_asset_decimals = MAX_ASSET_DECIMALS
 logic_sig_max_cost = LOGIC_SIG_MAX_COST
 logic_sig_max_size = LOGIC_SIG_MAX_SIZE
 app_page_max_size = APP_PAGE_MAX_SIZE
+stateproof_txn = STATEPROOF_TXN
