@@ -1,6 +1,7 @@
 import base64
 import json
 import os
+import warnings
 
 from . import constants
 from . import error
@@ -14,6 +15,10 @@ opcodes = None
 
 def check_program(program, args=None):
     """
+    NOTE: This method is deprecated:
+    Validation relies on metadata (`langspec.json`) that does not accurately represent opcode behavior across program versions.
+    The behavior of `check_program` relies on `langspec.json`. Thus, this method is being deprecated.
+
     Performs program checking for max length and cost
 
     Args:
@@ -26,11 +31,29 @@ def check_program(program, args=None):
     Raises:
         InvalidProgram: on error
     """
+    warnings.warn(
+        "`check_program` relies on metadata (`langspec.json`) that "
+        "does not accurately represent opcode behavior across program versions. "
+        "This method is being deprecated.",
+        DeprecationWarning,
+    )
     ok, _, _ = read_program(program, args)
     return ok
 
 
 def read_program(program, args=None):
+    """
+    NOTE: This method is deprecated:
+    Validation relies on metadata (`langspec.json`) that does not accurately represent opcode behavior across program versions.
+    The behavior of `read_program` relies on `langspec.json`. Thus, this method is being deprecated.
+    """
+    warnings.warn(
+        "`read_program` relies on metadata (`langspec.json`) that "
+        "does not accurately represent opcode behavior across program versions. "
+        "This method is being deprecated.",
+        DeprecationWarning,
+    )
+
     global spec, opcodes
     intcblock_opcode = 32
     bytecblock_opcode = 38
@@ -107,11 +130,25 @@ def read_program(program, args=None):
 
 
 def check_int_const_block(program, pc):
+    """
+    NOTE: This method is deprecated
+    """
+    warnings.warn(
+        "This method is being deprecated.",
+        DeprecationWarning,
+    )
     size, _ = read_int_const_block(program, pc)
     return size
 
 
 def read_int_const_block(program, pc):
+    """
+    NOTE: This method is deprecated
+    """
+    warnings.warn(
+        "This method is being deprecated.",
+        DeprecationWarning,
+    )
     size = 1
     ints = []
     num_ints, bytes_used = parse_uvarint(program[pc + size :])
@@ -134,11 +171,25 @@ def read_int_const_block(program, pc):
 
 
 def check_byte_const_block(program, pc):
+    """
+    NOTE: This method is deprecated
+    """
+    warnings.warn(
+        "This method is being deprecated.",
+        DeprecationWarning,
+    )
     size, _ = read_byte_const_block(program, pc)
     return size
 
 
 def read_byte_const_block(program, pc):
+    """
+    NOTE: This method is deprecated
+    """
+    warnings.warn(
+        "This method is being deprecated.",
+        DeprecationWarning,
+    )
     size = 1
     bytearrays = []
     num_ints, bytes_used = parse_uvarint(program[pc + size :])
@@ -164,11 +215,25 @@ def read_byte_const_block(program, pc):
 
 
 def check_push_int_block(program, pc):
+    """
+    NOTE: This method is deprecated
+    """
+    warnings.warn(
+        "This method is being deprecated.",
+        DeprecationWarning,
+    )
     size, _ = read_push_int_block(program, pc)
     return size
 
 
 def read_push_int_block(program, pc):
+    """
+    NOTE: This method is deprecated
+    """
+    warnings.warn(
+        "This method is being deprecated.",
+        DeprecationWarning,
+    )
     size = 1
     single_int, bytes_used = parse_uvarint(program[pc + size :])
     if bytes_used <= 0:
@@ -180,11 +245,25 @@ def read_push_int_block(program, pc):
 
 
 def check_push_byte_block(program, pc):
+    """
+    NOTE: This method is deprecated
+    """
+    warnings.warn(
+        "This method is being deprecated.",
+        DeprecationWarning,
+    )
     size, _ = read_push_byte_block(program, pc)
     return size
 
 
 def read_push_byte_block(program, pc):
+    """
+    NOTE: This method is deprecated
+    """
+    warnings.warn(
+        "This method is being deprecated.",
+        DeprecationWarning,
+    )
     size = 1
     item_len, bytes_used = parse_uvarint(program[pc + size :])
     if bytes_used <= 0:
@@ -200,6 +279,13 @@ def read_push_byte_block(program, pc):
 
 
 def parse_uvarint(buf):
+    """
+    NOTE: This method is deprecated
+    """
+    warnings.warn(
+        "This method is being deprecated.",
+        DeprecationWarning,
+    )
     x = 0
     s = 0
     for i, b in enumerate(buf):
